pub struct v128(/* private fields */);Available on WebAssembly only.
WASM-specific 128-bit wide SIMD vector type.
This type corresponds to the v128 type in the WebAssembly SIMD
proposal. This type is 128-bits
large and the meaning of all the bits is defined within the context of
how this value is used.
This same type is used simultaneously for all 128-bit-wide SIMD types, for example:
- sixteen 8-bit integers (both
i8andu8) - eight 16-bit integers (both
i16andu16) - four 32-bit integers (both
i32andu32) - two 64-bit integers (both
i64andu64) - four 32-bit floats (
f32) - two 64-bit floats (
f64)
The v128 type in Rust is intended to be quite analogous to the v128
type in WebAssembly. Operations on v128 can only be performed with the
functions in this module.